@@ -291,6 +291,12 @@ class A10ProviderDriver(driver_base.ProviderDriver):
                         raise Exception('end-address is required for nat-pool-list flavor')
                     if 'netmask' not in nat:
                         raise Exception('netmask is required for nat-pool-list flavor')
+            if 'deployment' in flavor_dict:
+                deployment = flavor_dict['deployment']
+                if ('dsr_type' in deployment and
+                        deployment['dsr_type'] not in ['l2dsr_transparent']):
+                    raise Exception('l2dsr_transparent is required value for dsr_type')
+
         except js_exceptions.ValidationError as e:
             error_object = ''
             if e.relative_path:
