@@ -582,8 +582,7 @@ class LoadBalancerFlows(object):
             provides=constants.FLAVOR_DATA))
         update_LB_flow.add(vthunder_tasks.GetVthunderConfByFlavor(
             inject={a10constants.VTHUNDER_CONFIG: vthunder_conf,
-                    a10constants.DEVICE_CONFIG_DICT: device_dict,
-                    a10constants.FLOW_TYPE: a10constants.UPDATE_FLOW},
+                    a10constants.DEVICE_CONFIG_DICT: device_dict},
             requires=(constants.LOADBALANCER, a10constants.VTHUNDER_CONFIG,
                       a10constants.DEVICE_CONFIG_DICT, constants.FLAVOR_DATA),
             provides=(a10constants.VTHUNDER_CONFIG, a10constants.USE_DEVICE_FLAVOR)))
@@ -646,8 +645,7 @@ class LoadBalancerFlows(object):
             provides=constants.FLAVOR_DATA))
         lb_create_flow.add(vthunder_tasks.GetVthunderConfByFlavor(
             inject={a10constants.VTHUNDER_CONFIG: vthunder_conf,
-                    a10constants.DEVICE_CONFIG_DICT: device_dict,
-                    a10constants.FLOW_TYPE: a10constants.CREATE_FLOW},
+                    a10constants.DEVICE_CONFIG_DICT: device_dict},
             requires=(constants.LOADBALANCER, a10constants.VTHUNDER_CONFIG,
                       a10constants.DEVICE_CONFIG_DICT, constants.FLAVOR_DATA),
             provides=(a10constants.VTHUNDER_CONFIG, a10constants.USE_DEVICE_FLAVOR)))
@@ -707,8 +705,7 @@ class LoadBalancerFlows(object):
             provides=constants.FLAVOR_DATA))
         delete_LB_flow.add(vthunder_tasks.GetVthunderConfByFlavor(
             inject={a10constants.VTHUNDER_CONFIG: vthunder_conf,
-                    a10constants.DEVICE_CONFIG_DICT: device_dict,
-                    a10constants.FLOW_TYPE: a10constants.DELETE_FLOW},
+                    a10constants.DEVICE_CONFIG_DICT: device_dict},
             requires=(constants.LOADBALANCER, a10constants.VTHUNDER_CONFIG,
                       a10constants.DEVICE_CONFIG_DICT, constants.FLAVOR_DATA),
             provides=(a10constants.VTHUNDER_CONFIG, a10constants.USE_DEVICE_FLAVOR)))
@@ -825,8 +822,7 @@ class LoadBalancerFlows(object):
             a10_database_tasks.GetVRIDForLoadbalancerResource(
                 requires=[
                     a10constants.PARTITION_PROJECT_LIST,
-                    a10constants.VTHUNDER,
-                    a10constants.USE_DEVICE_FLAVOR],
+                    a10constants.VTHUNDER],
                 provides=a10constants.VRID_LIST))
         handle_vrid_for_lb_subflow.add(vthunder_tasks.ConfigureVRID(
             requires=a10constants.VTHUNDER))
@@ -845,8 +841,7 @@ class LoadBalancerFlows(object):
             a10_database_tasks.UpdateVRIDForLoadbalancerResource(
                 requires=[
                     a10constants.VRID_LIST,
-                    a10constants.VTHUNDER_CONFIG,
-                    a10constants.USE_DEVICE_FLAVOR],
+                    a10constants.VTHUNDER],
                 rebind={
                     a10constants.LB_RESOURCE: constants.LOADBALANCER}))
         return handle_vrid_for_lb_subflow
@@ -873,8 +868,7 @@ class LoadBalancerFlows(object):
             a10_database_tasks.GetVRIDForLoadbalancerResource(
                 requires=[
                     a10constants.PARTITION_PROJECT_LIST,
-                    a10constants.VTHUNDER,
-                    a10constants.USE_DEVICE_FLAVOR],
+                    a10constants.VTHUNDER],
                 provides=a10constants.VRID_LIST))
         delete_lb_vrid_subflow.add(
             a10_network_tasks.DeleteVRIDPort(
@@ -909,8 +903,7 @@ class LoadBalancerFlows(object):
             a10_database_tasks.GetVRIDForLoadbalancerResource(
                 requires=[
                     a10constants.PARTITION_PROJECT_LIST,
-                    a10constants.VTHUNDER,
-                    a10constants.USE_DEVICE_FLAVOR],
+                    a10constants.VTHUNDER],
                 provides=a10constants.VRID_LIST))
         delete_lb_vrid_subflow.add(
             a10_network_tasks.DeleteVRIDPort(
@@ -946,7 +939,19 @@ class LoadBalancerFlows(object):
         """
         pools_listeners_delete_flow = linear_flow.Flow('pool_listener_delete_flow')
         store = {}
-        # loop fo loadbalancer's pool deletion
+        # loop for loadbalancer's l7policy deletion
+        l7policy_delete_flow = None
+        for listener in lb.listeners:
+            l7policy_delete_flow = linear_flow.Flow('l7policy_delete_flow')
+            for l7policy in listener.l7policies:
+                l7policy_name = 'l7policy_' + l7policy.id
+                store[l7policy_name] = l7policy
+                l7policy_delete_flow.add(
+                    self._l7policy_flows.get_cascade_delete_l7policy_internal_flow(l7policy_name))
+        if l7policy_delete_flow:
+            pools_listeners_delete_flow.add(l7policy_delete_flow)
+
+        # loop for loadbalancer's pool deletion
         for pool in lb.pools:
             pool_name = 'pool' + pool.id
             members = pool.members
@@ -971,13 +976,6 @@ class LoadBalancerFlows(object):
         listeners_delete_flow = unordered_flow.Flow('listener_delete_flow')
         compute_flag = lb.amphorae
         for listener in lb.listeners:
-            l7policy_delete_flow = linear_flow.Flow('l7policy_delete_flow')
-            for l7policy in listener.l7policies:
-                l7policy_name = 'l7policy_' + l7policy.id
-                store[l7policy_name] = l7policy
-                l7policy_delete_flow.add(
-                    self._l7policy_flows.get_cascade_delete_l7policy_internal_flow(l7policy_name))
-            listeners_delete_flow.add(l7policy_delete_flow)
             listener_name = 'listener_' + listener.id
             store[listener_name] = listener
             listeners_delete_flow.add(
