@@ -270,6 +270,10 @@ class PoolFlows(object):
         delete_pool_flow.add(model_tasks.DeleteModelObject(
             name='delete_model_object_' + pool_name,
             rebind={constants.OBJECT: pool_name}))
+        delete_pool_flow.add(a10_network_tasks.GetPoolsOnThunder(
+            name='get_pools_on_thunder_' + pool_name,
+            requires=[a10constants.VTHUNDER, a10constants.USE_DEVICE_FLAVOR],
+            provides=a10constants.POOLS))
         # Delete pool children
         delete_pool_flow.add(self._get_delete_health_monitor_vthunder_subflow(health_mon, True))
         delete_pool_flow.add(self._get_delete_member_vthunder_subflow(members, store, pool_name))
@@ -315,6 +319,20 @@ class PoolFlows(object):
         delete_pool_flow.add(vthunder_tasks.SetupDeviceNetworkMap(
             requires=a10constants.VTHUNDER,
             provides=a10constants.VTHUNDER))
+
+        # Device Flavor
+        delete_pool_flow.add(a10_database_tasks.GetFlavorData(
+            rebind={a10constants.LB_RESOURCE: constants.LOADBALANCER},
+            provides=constants.FLAVOR))
+        delete_pool_flow.add(vthunder_tasks.GetVthunderConfByFlavor(
+            requires=(constants.LOADBALANCER, a10constants.VTHUNDER_CONFIG,
+                      a10constants.DEVICE_CONFIG_DICT),
+            rebind={constants.FLAVOR_DATA: constants.FLAVOR},
+            provides=(a10constants.VTHUNDER_CONFIG, a10constants.USE_DEVICE_FLAVOR)))
+        delete_pool_flow.add(a10_network_tasks.GetPoolsOnThunder(
+            requires=[a10constants.VTHUNDER, a10constants.USE_DEVICE_FLAVOR],
+            provides=a10constants.POOLS))
+
         # Delete pool children
         delete_pool_flow.add(self._get_delete_health_monitor_vthunder_subflow(health_mon))
         delete_pool_flow.add(self._get_delete_member_vthunder_subflow(members, store))
