@@ -22,6 +22,7 @@ from a10_octavia.common import a10constants
 from a10_octavia.common import exceptions
 from a10_octavia.common import openstack_mappings
 from a10_octavia.controller.worker.tasks.decorators import axapi_client_decorator
+from a10_octavia.controller.worker.tasks.decorators import axapi_client_decorator_for_revert
 from a10_octavia.controller.worker.tasks import utils
 
 CONF = cfg.CONF
@@ -159,6 +160,8 @@ class ListenersParent(object):
                    virtual_port_templates=vport_templates,
                    **config_data)
 
+        listener.protocol = listener.protocol.upper()
+
 
 class ListenerCreate(ListenersParent, task.Task):
     """Task to create listener"""
@@ -173,7 +176,7 @@ class ListenerCreate(ListenersParent, task.Task):
             LOG.exception("Failed to create listener: %s", listener.id)
             raise e
 
-    @axapi_client_decorator
+    @axapi_client_decorator_for_revert
     def revert(self, loadbalancer, listener, vthunder, *args, **kwargs):
         LOG.warning("Reverting creation of listener: %s", listener.id)
         try:
@@ -210,6 +213,7 @@ class ListenerUpdateForPool(ListenersParent, task.Task):
     def execute(self, loadbalancer, listener, vthunder):
         try:
             if listener:
+                c_pers, s_pers = utils.get_sess_pers_templates(listener.default_pool)
                 listener.protocol = openstack_mappings.virtual_port_protocol(
                     self.axapi_client, listener.protocol).lower()
                 self.axapi_client.slb.virtual_server.vport.update(
@@ -217,7 +221,8 @@ class ListenerUpdateForPool(ListenersParent, task.Task):
                     listener.id,
                     listener.protocol,
                     listener.protocol_port,
-                    listener.default_pool_id)
+                    listener.default_pool_id,
+                    s_pers_name=s_pers, c_pers_name=c_pers)
                 LOG.debug("Successfully updated listener: %s", listener.id)
         except (acos_errors.ACOSException, ConnectionError) as e:
             LOG.exception("Failed to update listener: %s", listener.id)
