@@ -1214,8 +1214,7 @@ class VthunderInstanceBusy(VThunderBaseTask):
 
 class GetVthunderConfByFlavor(VThunderBaseTask):
 
-    def execute(self, loadbalancer, vthunder_config, device_config_dict, flavor_data=None,
-                flow_type=None):
+    def execute(self, loadbalancer, vthunder_config, device_config_dict, flavor_data=None):
         if flavor_data is None and vthunder_config is None:
             raise exceptions.ProjectDeviceNotFound()
 
@@ -1225,9 +1224,6 @@ class GetVthunderConfByFlavor(VThunderBaseTask):
                 dev_key = a10constants.DEVICE_KEY_PREFIX + device_flavor
                 if dev_key in device_config_dict:
                     vthunder_config = device_config_dict[dev_key]
-                    if flow_type is None or flow_type == a10constants.CREATE_FLOW:
-                        if vthunder_config.project_id is not None:
-                            raise exceptions.DeviceIsProjectDevice()
                     vthunder_config.project_id = loadbalancer.project_id
                     if vthunder_config.hierarchical_multitenancy == "enable":
                         vthunder_config.partition_name = loadbalancer.project_id[0:14]
