@@ -461,20 +461,12 @@ class VRIDRepository(BaseRepository):
 
     # A project can have multiple VRIDs, so need to convert each vrid object through
     # "to_data_model"
-    def get_vrid_from_project_ids(self, session, project_ids):
-        vrid_obj_list = []
-        model = session.query(self.model_class).filter(
-            self.model_class.owner.in_(project_ids))
-        for data in model:
-            vrid_obj_list.append(data.to_data_model())
-
-        return vrid_obj_list
-
-    def get_vrid_from_owner(self, session, owner):
+    def get_vrid_from_owner(self, session, owner, project_ids):
         vrid_obj_list = []
 
         model = session.query(self.model_class).filter(
-            self.model_class.owner == owner)
+            or_(self.model_class.owner == owner,
+                self.model_class.owner.in_(project_ids)))
         for data in model:
             vrid_obj_list.append(data.to_data_model())
 
